diff --git a/README.md b/README.md
index 0dcd34560..9571a3a9c 100644
--- a/README.md
+++ b/README.md
@@ -148,7 +148,7 @@ TODO
+ *Version*: 2.12.2
+ *Copyright*: Copyright (C) 2015 - 2020 Vast Development Method. All rights reserved.
+ *License*: GNU General Public License version 2 or later; see LICENSE.txt
-+ *Line count*: **289867**
++ *Line count*: **290337**
+ *Field count*: **1555**
+ *File count*: **1923**
+ *Folder count*: **316**
diff --git a/admin/README.txt b/admin/README.txt
index 0dcd34560..9571a3a9c 100644
--- a/admin/README.txt
+++ b/admin/README.txt
@@ -148,7 +148,7 @@ TODO
+ *Version*: 2.12.2
+ *Copyright*: Copyright (C) 2015 - 2020 Vast Development Method. All rights reserved.
+ *License*: GNU General Public License version 2 or later; see LICENSE.txt
-+ *Line count*: **289867**
++ *Line count*: **290337**
+ *Field count*: **1555**
+ *File count*: **1923**
+ *Folder count*: **316**
diff --git a/admin/models/admin_views.php b/admin/models/admin_views.php
index 748b65187..8931bf9b4 100644
--- a/admin/models/admin_views.php
+++ b/admin/models/admin_views.php
@@ -679,12 +679,32 @@ class ComponentbuilderModelAdmin_views extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
$id .= ':' . $this->getState('filter.add_fadein');
- $id .= ':' . $this->getState('filter.type');
+ // Check if the value is an array
+ $_type = $this->getState('filter.type');
+ if (ComponentbuilderHelper::checkArray($_type))
+ {
+ $id .= ':' . implode(':', $_type);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_type))
+ {
+ $id .= ':' . $_type;
+ }
$id .= ':' . $this->getState('filter.add_custom_button');
$id .= ':' . $this->getState('filter.add_php_ajax');
$id .= ':' . $this->getState('filter.add_custom_import');
diff --git a/admin/models/admins_custom_tabs.php b/admin/models/admins_custom_tabs.php
index e79220393..eca17e12c 100644
--- a/admin/models/admins_custom_tabs.php
+++ b/admin/models/admins_custom_tabs.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelAdmins_custom_tabs extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/admins_fields.php b/admin/models/admins_fields.php
index e55d376e1..01036d6a2 100644
--- a/admin/models/admins_fields.php
+++ b/admin/models/admins_fields.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelAdmins_fields extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/admins_fields_conditions.php b/admin/models/admins_fields_conditions.php
index 2ea69a40f..1cef82ca1 100644
--- a/admin/models/admins_fields_conditions.php
+++ b/admin/models/admins_fields_conditions.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelAdmins_fields_conditions extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/admins_fields_relations.php b/admin/models/admins_fields_relations.php
index ac101022b..71448255f 100644
--- a/admin/models/admins_fields_relations.php
+++ b/admin/models/admins_fields_relations.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelAdmins_fields_relations extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/class_extendings.php b/admin/models/class_extendings.php
index d34a6e84f..4b052ca88 100644
--- a/admin/models/class_extendings.php
+++ b/admin/models/class_extendings.php
@@ -284,7 +284,17 @@ class ComponentbuilderModelClass_extendings extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/class_methods.php b/admin/models/class_methods.php
index 38a6dfe5c..fe0f77883 100644
--- a/admin/models/class_methods.php
+++ b/admin/models/class_methods.php
@@ -457,7 +457,17 @@ class ComponentbuilderModelClass_methods extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/class_properties.php b/admin/models/class_properties.php
index 6eaa225f6..463587c7b 100644
--- a/admin/models/class_properties.php
+++ b/admin/models/class_properties.php
@@ -455,7 +455,17 @@ class ComponentbuilderModelClass_properties extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_admin_views.php b/admin/models/components_admin_views.php
index 0cf48fadd..04c86467d 100644
--- a/admin/models/components_admin_views.php
+++ b/admin/models/components_admin_views.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_admin_views extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_config.php b/admin/models/components_config.php
index 05834e3ec..32ebdf777 100644
--- a/admin/models/components_config.php
+++ b/admin/models/components_config.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_config extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_custom_admin_menus.php b/admin/models/components_custom_admin_menus.php
index c0cb22b26..fdc4bfbb0 100644
--- a/admin/models/components_custom_admin_menus.php
+++ b/admin/models/components_custom_admin_menus.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_custom_admin_menus extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_custom_admin_views.php b/admin/models/components_custom_admin_views.php
index 6880647a7..b45955984 100644
--- a/admin/models/components_custom_admin_views.php
+++ b/admin/models/components_custom_admin_views.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_custom_admin_views extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_dashboard.php b/admin/models/components_dashboard.php
index 4a93f3043..d27a32e20 100644
--- a/admin/models/components_dashboard.php
+++ b/admin/models/components_dashboard.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_dashboard extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_files_folders.php b/admin/models/components_files_folders.php
index 88100176c..dc0807c3c 100644
--- a/admin/models/components_files_folders.php
+++ b/admin/models/components_files_folders.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_files_folders extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_modules.php b/admin/models/components_modules.php
index dbaaeea92..76121cf24 100644
--- a/admin/models/components_modules.php
+++ b/admin/models/components_modules.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_modules extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_mysql_tweaks.php b/admin/models/components_mysql_tweaks.php
index 9f0ff8646..1aab5f630 100644
--- a/admin/models/components_mysql_tweaks.php
+++ b/admin/models/components_mysql_tweaks.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_mysql_tweaks extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_placeholders.php b/admin/models/components_placeholders.php
index ae5cdd222..bcdb62bba 100644
--- a/admin/models/components_placeholders.php
+++ b/admin/models/components_placeholders.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_placeholders extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_plugins.php b/admin/models/components_plugins.php
index 654f2ff25..75183b57d 100644
--- a/admin/models/components_plugins.php
+++ b/admin/models/components_plugins.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_plugins extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_site_views.php b/admin/models/components_site_views.php
index 11024a95d..aa3080caf 100644
--- a/admin/models/components_site_views.php
+++ b/admin/models/components_site_views.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_site_views extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/components_updates.php b/admin/models/components_updates.php
index 99c9dfd75..4808ddc29 100644
--- a/admin/models/components_updates.php
+++ b/admin/models/components_updates.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelComponents_updates extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/custom_admin_views.php b/admin/models/custom_admin_views.php
index 0e44c6be2..20a8109ae 100644
--- a/admin/models/custom_admin_views.php
+++ b/admin/models/custom_admin_views.php
@@ -513,7 +513,17 @@ class ComponentbuilderModelCustom_admin_views extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/custom_codes.php b/admin/models/custom_codes.php
index 9d3e88c00..2c61f7028 100644
--- a/admin/models/custom_codes.php
+++ b/admin/models/custom_codes.php
@@ -549,7 +549,17 @@ class ComponentbuilderModelCustom_codes extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/dynamic_gets.php b/admin/models/dynamic_gets.php
index a6d06820f..329ee30b3 100644
--- a/admin/models/dynamic_gets.php
+++ b/admin/models/dynamic_gets.php
@@ -464,7 +464,17 @@ class ComponentbuilderModelDynamic_gets extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/fields.php b/admin/models/fields.php
index 734b7dadc..310c61733 100644
--- a/admin/models/fields.php
+++ b/admin/models/fields.php
@@ -632,7 +632,17 @@ class ComponentbuilderModelFields extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/fieldtypes.php b/admin/models/fieldtypes.php
index 9cb909ac5..46b7b714a 100644
--- a/admin/models/fieldtypes.php
+++ b/admin/models/fieldtypes.php
@@ -393,7 +393,17 @@ class ComponentbuilderModelFieldtypes extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_components.php b/admin/models/joomla_components.php
index 44a8fa786..17f97a648 100644
--- a/admin/models/joomla_components.php
+++ b/admin/models/joomla_components.php
@@ -2511,7 +2511,17 @@ class ComponentbuilderModelJoomla_components extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_modules.php b/admin/models/joomla_modules.php
index 2bfbde2ff..9054a340c 100644
--- a/admin/models/joomla_modules.php
+++ b/admin/models/joomla_modules.php
@@ -290,7 +290,17 @@ class ComponentbuilderModelJoomla_modules extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_modules_files_folders_urls.php b/admin/models/joomla_modules_files_folders_urls.php
index 2adf63f2d..a8c0151d4 100644
--- a/admin/models/joomla_modules_files_folders_urls.php
+++ b/admin/models/joomla_modules_files_folders_urls.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelJoomla_modules_files_folders_urls extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_modules_updates.php b/admin/models/joomla_modules_updates.php
index eb8c309f2..f6d6d71a2 100644
--- a/admin/models/joomla_modules_updates.php
+++ b/admin/models/joomla_modules_updates.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelJoomla_modules_updates extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_plugin_groups.php b/admin/models/joomla_plugin_groups.php
index 7ccdafdcc..e1b0fe3b0 100644
--- a/admin/models/joomla_plugin_groups.php
+++ b/admin/models/joomla_plugin_groups.php
@@ -231,7 +231,17 @@ class ComponentbuilderModelJoomla_plugin_groups extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_plugins.php b/admin/models/joomla_plugins.php
index 7f010891e..b77d3b8a2 100644
--- a/admin/models/joomla_plugins.php
+++ b/admin/models/joomla_plugins.php
@@ -451,7 +451,17 @@ class ComponentbuilderModelJoomla_plugins extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_plugins_files_folders_urls.php b/admin/models/joomla_plugins_files_folders_urls.php
index 62ff159fe..bdfc44211 100644
--- a/admin/models/joomla_plugins_files_folders_urls.php
+++ b/admin/models/joomla_plugins_files_folders_urls.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelJoomla_plugins_files_folders_urls extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/joomla_plugins_updates.php b/admin/models/joomla_plugins_updates.php
index 25e08bae6..a0ba866fa 100644
--- a/admin/models/joomla_plugins_updates.php
+++ b/admin/models/joomla_plugins_updates.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelJoomla_plugins_updates extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/language_translations.php b/admin/models/language_translations.php
index cd1fe680e..eb64dee0d 100644
--- a/admin/models/language_translations.php
+++ b/admin/models/language_translations.php
@@ -450,7 +450,17 @@ class ComponentbuilderModelLanguage_translations extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/languages.php b/admin/models/languages.php
index efe450d61..01bbbccb8 100644
--- a/admin/models/languages.php
+++ b/admin/models/languages.php
@@ -476,7 +476,17 @@ class ComponentbuilderModelLanguages extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/layouts.php b/admin/models/layouts.php
index d3a436cf1..f89753e1f 100644
--- a/admin/models/layouts.php
+++ b/admin/models/layouts.php
@@ -445,7 +445,17 @@ class ComponentbuilderModelLayouts extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/libraries.php b/admin/models/libraries.php
index eb280227c..67b769367 100644
--- a/admin/models/libraries.php
+++ b/admin/models/libraries.php
@@ -377,7 +377,17 @@ class ComponentbuilderModelLibraries extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/libraries_config.php b/admin/models/libraries_config.php
index beb1a291f..7926c4c79 100644
--- a/admin/models/libraries_config.php
+++ b/admin/models/libraries_config.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelLibraries_config extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/libraries_files_folders_urls.php b/admin/models/libraries_files_folders_urls.php
index cfb31ee06..d573a9f0a 100644
--- a/admin/models/libraries_files_folders_urls.php
+++ b/admin/models/libraries_files_folders_urls.php
@@ -204,7 +204,17 @@ class ComponentbuilderModelLibraries_files_folders_urls extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/placeholders.php b/admin/models/placeholders.php
index 7eeea84b5..4ff20c219 100644
--- a/admin/models/placeholders.php
+++ b/admin/models/placeholders.php
@@ -357,7 +357,17 @@ class ComponentbuilderModelPlaceholders extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/servers.php b/admin/models/servers.php
index e2494f10d..46bca9476 100644
--- a/admin/models/servers.php
+++ b/admin/models/servers.php
@@ -472,7 +472,17 @@ class ComponentbuilderModelServers extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/site_views.php b/admin/models/site_views.php
index b3973fd6d..8059aeb58 100644
--- a/admin/models/site_views.php
+++ b/admin/models/site_views.php
@@ -521,7 +521,17 @@ class ComponentbuilderModelSite_views extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/snippet_types.php b/admin/models/snippet_types.php
index 66ba91cd0..d127fa3a0 100644
--- a/admin/models/snippet_types.php
+++ b/admin/models/snippet_types.php
@@ -231,7 +231,17 @@ class ComponentbuilderModelSnippet_types extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/snippets.php b/admin/models/snippets.php
index d5ecd65e0..e04c2ca48 100644
--- a/admin/models/snippets.php
+++ b/admin/models/snippets.php
@@ -535,7 +535,17 @@ class ComponentbuilderModelSnippets extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/templates.php b/admin/models/templates.php
index 2071d4758..a2e7105bc 100644
--- a/admin/models/templates.php
+++ b/admin/models/templates.php
@@ -445,7 +445,17 @@ class ComponentbuilderModelTemplates extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/models/validation_rules.php b/admin/models/validation_rules.php
index 5b6fd0655..427255941 100644
--- a/admin/models/validation_rules.php
+++ b/admin/models/validation_rules.php
@@ -355,7 +355,17 @@ class ComponentbuilderModelValidation_rules extends JModelList
$id .= ':' . $this->getState('filter.id');
$id .= ':' . $this->getState('filter.search');
$id .= ':' . $this->getState('filter.published');
- $id .= ':' . $this->getState('filter.access');
+ // Check if the value is an array
+ $_filter = $this->getState('filter.access');
+ if (ComponentbuilderHelper::checkArray($_filter))
+ {
+ $id .= ':' . implode(':', $_filter);
+ }
+ // This should not happen, but we try
+ elseif (is_numeric($_filter))
+ {
+ $id .= ':' . $_filter;
+ }
$id .= ':' . $this->getState('filter.ordering');
$id .= ':' . $this->getState('filter.created_by');
$id .= ':' . $this->getState('filter.modified_by');
diff --git a/admin/helpers/compiler/e_Interpretation.php b/admin/helpers/compiler/e_Interpretation.php
index 3e4afcb90..e19401579 100644
--- a/admin/helpers/compiler/e_Interpretation.php
+++ b/admin/helpers/compiler/e_Interpretation.php
@@ -5053,7 +5053,7 @@ class Interpretation extends Fields
public function setAdminViewDisplayMethod($nameListCode)
{
$script = '';
- // add the the new filter methods for the search toolbar above the list view
+ // add the the new filter methods for the search toolbar above the list view (2 = topbar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
{
@@ -12035,7 +12035,7 @@ class Interpretation extends Fields
// build the body
$body = array();
- // check if the filter type is sidebar
+ // check if the filter type is sidebar (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1)
{
@@ -12075,7 +12075,7 @@ class Interpretation extends Fields
$body[] = "";
$body[] = $this->_t(1) . "
";
$body[] = "";
- // check if the filter type is sidebar
+ // check if the filter type is sidebar (2 = topbar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
{
@@ -12088,7 +12088,7 @@ class Interpretation extends Fields
$body[] = "?>";
}
$body[] = "items)): ?>";
- // check if the filter type is sidebar
+ // check if the filter type is sidebar (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1)
{
@@ -12101,7 +12101,7 @@ class Interpretation extends Fields
. "";
$body[] = $this->_t(1) . "
";
$body[] = "";
- // check if the filter type is sidebar
+ // check if the filter type is sidebar (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1)
{
@@ -12135,7 +12135,7 @@ class Interpretation extends Fields
$body[] = $this->_t(3) . "\$this->loadTemplate('batch_body')";
$body[] = $this->_t(2) . "); ?>";
$body[] = $this->_t(1) . "";
- // check if the filter type is sidebar
+ // check if the filter type is sidebar (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1)
{
@@ -12175,7 +12175,7 @@ class Interpretation extends Fields
$jhtml_sort = "grid.sort";
$jhtml_sort_icon = "";
$jhtml_sort_icon_2 = "";
- // for the new filter
+ // for the new filter (2 = topbar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
{
@@ -15810,7 +15810,7 @@ class Interpretation extends Fields
. $this->setLine(__LINE__) . " Filter by "
. ucwords($filter['code']) . ".";
// we only add multi filter option if new filter type
- // and we have multi filter set for this field
+ // and we have multi filter set for this field (2 = topbar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2
&& isset($filter['multi'])
@@ -17671,7 +17671,7 @@ class Interpretation extends Fields
$this->filterBuilder[$nameListCode]
))
{
- // set the function or file path
+ // set the function or file path (2 = topbar)
$funtion_path = true;
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
@@ -18121,7 +18121,7 @@ class Interpretation extends Fields
);
// add the category filter stuff
$this->setCategorySidebarFilterHelper($fieldFilters, $nameListCode);
- // check if filter fields are added
+ // check if filter fields are added (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1
&& isset($this->filterBuilder[$nameListCode])
@@ -18289,7 +18289,7 @@ class Interpretation extends Fields
protected function setDefaultSidebarFilterHelper(&$filter, &$nameSingleCode,
&$nameListCode
) {
- // add the default filters if we are on the old filter paths
+ // add the default filters if we are on the old filter paths (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1)
{
@@ -18337,7 +18337,7 @@ class Interpretation extends Fields
*/
protected function setCategorySidebarFilterHelper(&$filter, &$nameListCode)
{
- // add the category filter if we are on the old filter paths
+ // add the category filter if we are on the old filter paths (1 = sidebar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 1
&& isset($this->categoryBuilder[$nameListCode])
@@ -18384,7 +18384,7 @@ class Interpretation extends Fields
$this->filterBuilder[$nameListCode]
))
{
- // check if we should add some help to get the values
+ // check if we should add some help to get the values (2 = topbar)
$get_values = false;
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
@@ -20479,6 +20479,8 @@ class Interpretation extends Fields
*/
public function setStoredId(&$nameSingleCode, &$nameListCode)
{
+ // set component name
+ $Component = ucwords($this->componentCodeName);
// keep track of all fields already added
$donelist = array('id' => true, 'search' => true,
'published' => true, 'access' => true,
@@ -20489,22 +20491,70 @@ class Interpretation extends Fields
. "\$id .= ':' . \$this->getState('filter.id');";
$stored .= PHP_EOL . $this->_t(2)
. "\$id .= ':' . \$this->getState('filter.search');";
- $stored .= PHP_EOL . $this->_t(2)
- . "\$id .= ':' . \$this->getState('filter.published');";
+ // add this if not already added
+ if (!isset($this->fieldsNames[$nameSingleCode]['published']))
+ {
+ $stored .= PHP_EOL . $this->_t(2)
+ . "\$id .= ':' . \$this->getState('filter.published');";
+ }
+ // add if view calls for it, and not already added
if (isset($this->accessBuilder[$nameSingleCode])
&& ComponentbuilderHelper::checkString(
$this->accessBuilder[$nameSingleCode]
- ))
+ )
+ && !isset($this->fieldsNames[$nameSingleCode]['access']))
{
- $stored .= PHP_EOL . $this->_t(2)
- . "\$id .= ':' . \$this->getState('filter.access');";
+ // the side bar option is single
+ if (isset($this->adminFilterType[$nameListCode])
+ && $this->adminFilterType[$nameListCode] == 1)
+ {
+ $stored .= PHP_EOL . $this->_t(2)
+ . "\$id .= ':' . \$this->getState('filter.access');";
+ }
+ else
+ {
+ // top bar selection can result in
+ // an array due to multi selection
+ $stored .= PHP_EOL . $this->_t(2)
+ . "//" . $this->setLine(__LINE__)
+ . " Check if the value is an array";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "\$_filter = \$this->getState('filter.access');";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "if (" . $Component . "Helper::checkArray(\$_filter))";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "{";
+ $stored .= PHP_EOL . $this->_t(3)
+ . "\$id .= ':' . implode(':', \$_filter);";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "}";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "//" . $this->setLine(__LINE__)
+ . " This should not happen, but we try";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "elseif (is_numeric(\$_filter))";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "{";
+ $stored .= PHP_EOL . $this->_t(3)
+ . "\$id .= ':' . \$_filter;";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "}";
+ }
}
$stored .= PHP_EOL . $this->_t(2)
. "\$id .= ':' . \$this->getState('filter.ordering');";
- $stored .= PHP_EOL . $this->_t(2)
- . "\$id .= ':' . \$this->getState('filter.created_by');";
- $stored .= PHP_EOL . $this->_t(2)
- . "\$id .= ':' . \$this->getState('filter.modified_by');";
+ // add this if not already added
+ if (!isset($this->fieldsNames[$nameSingleCode]['created_by']))
+ {
+ $stored .= PHP_EOL . $this->_t(2)
+ . "\$id .= ':' . \$this->getState('filter.created_by');";
+ }
+ // add this if not already added
+ if (!isset($this->fieldsNames[$nameSingleCode]['modified_by']))
+ {
+ $stored .= PHP_EOL . $this->_t(2)
+ . "\$id .= ':' . \$this->getState('filter.modified_by');";
+ }
// add the rest of the set filters
if (isset($this->filterBuilder[$nameListCode])
&& ComponentbuilderHelper::checkArray(
@@ -20516,7 +20566,7 @@ class Interpretation extends Fields
if (!isset($donelist[$filter['code']]))
{
$stored .= $this->getStoredIdCode(
- $filter
+ $filter, $Component
);
$donelist[$filter['code']] = true;
}
@@ -20533,7 +20583,7 @@ class Interpretation extends Fields
if (!isset($donelist[$filter['code']]))
{
$stored .= $this->getStoredIdCode(
- $filter
+ $filter, $Component
);
$donelist[$filter['code']] = true;
}
@@ -20546,12 +20596,13 @@ class Interpretation extends Fields
/**
* Add the code of the stored ids
*
* @param array $filter The field/filter array
*
* @return string The code for the stored IDs
*
*/
- protected function getStoredIdCode(&$filter)
+ protected function getStoredIdCode(&$filter, &$Component)
{
if ($filter['type'] === 'category')
{
@@ -20568,9 +20619,43 @@ class Interpretation extends Fields
}
else
{
- $stored = PHP_EOL . $this->_t(2)
- . "\$id .= ':' . \$this->getState('filter."
- . $filter['code'] . "');";
+ if ($filter['multi'] == 2)
+ {
+ // top bar selection can result in
+ // an array due to multi selection
+ $stored .= PHP_EOL . $this->_t(2)
+ . "//" . $this->setLine(__LINE__)
+ . " Check if the value is an array";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "\$_" . $filter['code'] . " = \$this->getState('filter."
+ . $filter['code'] . "');";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "if (" . $Component . "Helper::checkArray(\$_"
+ . $filter['code'] . "))";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "{";
+ $stored .= PHP_EOL . $this->_t(3)
+ . "\$id .= ':' . implode(':', \$_" . $filter['code'] . ");";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "}";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "//" . $this->setLine(__LINE__)
+ . " This should not happen, but we try";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "elseif (is_numeric(\$_" . $filter['code'] . "))";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "{";
+ $stored .= PHP_EOL . $this->_t(3)
+ . "\$id .= ':' . \$_" . $filter['code'] . ";";
+ $stored .= PHP_EOL . $this->_t(2)
+ . "}";
+ }
+ else
+ {
+ $stored = PHP_EOL . $this->_t(2)
+ . "\$id .= ':' . \$this->getState('filter."
+ . $filter['code'] . "');";
+ }
}
return $stored;
@@ -20915,7 +21000,7 @@ class Interpretation extends Fields
$state = '';
// keep track of all fields already added
$donelist = array();
- // we must add the formSubmited code if new above filters is used
+ // we must add the formSubmited code if new above filters is used (2 = topbar)
$new_filter = false;
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
@@ -21985,7 +22070,7 @@ class Interpretation extends Fields
*/
protected function setChosenMultiSelectionHeaders(&$headers, $nameListCode)
{
- // check that the filter type is the new filter option
+ // check that the filter type is the new filter option (2 = topbar)
if (isset($this->adminFilterType[$nameListCode])
&& $this->adminFilterType[$nameListCode] == 2)
{
@@ -20546,12 +20596,13 @@ class Interpretation extends Fields
* Add the code of the stored ids
*
- * @param array $filter The field/filter array
+ * @param array $filter The field/filter array
+ * @param string $Component The Component name
*
* @return string The code for the stored IDs